@@ -1,7 +1,7 @@
 <?php
 /** Adminer - Compact database management
-* @link http://www.adminer.org/
-* @author Jakub Vrana, http://www.vrana.cz/
+* @link https://www.adminer.org/
+* @author Jakub Vrana, https://www.vrana.cz/
 * @copyright 2007 Jakub Vrana
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
@@ -65,6 +65,8 @@ if (isset($_GET["download"])) {
 	include "./user.inc.php";
 } elseif (isset($_GET["processlist"])) {
 	include "./processlist.inc.php";
+} elseif (isset($_GET["replication"])) {
+	include "./replication.inc.php";
 } elseif (isset($_GET["select"])) {
 	include "./select.inc.php";
 } elseif (isset($_GET["variables"])) {
