@@ -1,23 +1,22 @@
 <?php
 $translations = array(
 	'Login' => 'تسجيل الدخول',
-	'Logout successful.' => 'مع السلامة.',
-	'Invalid credentials.' => 'فشل في تسجيل الدخول.',
+	'Logout successful.' => 'تم تسجيل الخروج بنجاح.',
+	'Invalid credentials.' => 'بيانات الدخول غير صالحة.',
 	'Server' => 'الخادم',
-	'Username' => 'المستعمل',
+	'Username' => 'اسم المستخدم',
 	'Password' => 'كلمة المرور',
-	'Select database' => 'إختر قاعدة البيانات',
-	'Invalid database.' => 'قاعدة بيانات خاطئة.',
-	'Create new database' => 'أنشئ فاعدة بيانات',
+	'Select database' => 'اختر قاعدة البيانات',
+	'Invalid database.' => 'قاعدة البيانات غير صالحة.',
 	'Table has been dropped.' => 'تم حذف الجدول.',
 	'Table has been altered.' => 'تم تعديل الجدول.',
 	'Table has been created.' => 'تم إنشاء الجدول.',
 	'Alter table' => 'تعديل الجدول',
 	'Create table' => 'إنشاء جدول',
-	'Table name' => 'إسم الجدول',
+	'Table name' => 'اسم الجدول',
 	'engine' => 'المحرك',
 	'collation' => 'الترتيب',
-	'Column name' => 'إسم العمود',
+	'Column name' => 'اسم العمود',
 	'Type' => 'النوع',
 	'Length' => 'الطول',
 	'Auto Increment' => 'تزايد تلقائي',
@@ -29,10 +28,10 @@ $translations = array(
 	'Database has been altered.' => 'تم تعديل قاعدة البيانات.',
 	'Alter database' => 'تعديل قاعدة البيانات',
 	'Create database' => 'إنشاء قاعدة بيانات',
-	'SQL command' => 'إستعلام SQL',
+	'SQL command' => 'استعلام SQL',
 	'Logout' => 'تسجيل الخروج',
 	'database' => 'قاعدة بيانات',
-	'Use' => 'المستعمل',
+	'Use' => 'استعمال',
 	'No tables.' => 'لا توجد جداول.',
 	'select' => 'تحديد',
 	'Item has been deleted.' => 'تم حذف العنصر.',
@@ -48,48 +47,48 @@ $translations = array(
 	'Alter indexes' => 'تعديل المؤشرات',
 	'Add next' => 'إضافة التالي',
 	'Language' => 'اللغة',
-	'Select' => 'إختيار',
+	'Select' => 'اختيار',
 	'New item' => 'عنصر جديد',
 	'Search' => 'بحث',
 	'Sort' => 'ترتيب',
 	'descending' => 'تنازلي',
 	'Limit' => 'حد',
 	'No rows.' => 'لا توجد نتائج.',
-	'Action' => 'حركة',
+	'Action' => 'الإجراء',
 	'edit' => 'تعديل',
 	'Page' => 'صفحة',
-	'Query executed OK, %d row(s) affected.' => 'تم تنفسذ الإستعلام, %d عدد الأسطر المعدلة.',
-	'Error in query' => 'هناك خطأ في الإستعلام',
+	'Query executed OK, %d row(s) affected.' => 'تم تنفسذ الاستعلام, %d عدد الأسطر المعدلة.',
+	'Error in query' => 'هناك خطأ في الاستعلام',
 	'Execute' => 'تنفيذ',
 	'Table' => 'جدول',
 	'Foreign keys' => 'مفاتيح أجنبية',
 	'Triggers' => 'الزنادات',
 	'View' => 'عرض',
-	'Unable to select the table' => 'من غير الممكن إختيار الجدول',
-	'Invalid CSRF token. Send the form again.' => 'CSRF Token خاطئ. من فضلك أعد إرسال الإستمارة.',
+	'Unable to select the table' => 'يتعذر اختيار الجدول',
+	'Invalid CSRF token. Send the form again.' => 'رمز CSRF غير صالح. المرجو إرسال الاستمارة مرة أخرى.',
 	'Comment' => 'تعليق',
-	'Default values' => 'القيمة الإفتراضية',
+	'Default values' => 'القيم الافتراضية',
 	'%d byte(s)' => '%d بايت',
 	'No commands to execute.' => 'لا توجد أوامر للتنفيذ.',
-	'Unable to upload a file.' => 'من غير الممكن رفع الملف.',
+	'Unable to upload a file.' => 'يتعذر رفع ملف ما.',
 	'File upload' => 'رفع ملف',
-	'File uploads are disabled.' => 'تم إلغاء رفع الملفات.',
-	'Routine has been called, %d row(s) affected.' => 'تم إستدعاء الروتين, عدد الأسطر المعدلة %d.',
-	'Call' => 'إستدعاء',
-	'No extension' => 'إمتداد غير موجود',
+	'File uploads are disabled.' => 'رفع الملفات غير مشغل.',
+	'Routine has been called, %d row(s) affected.' => 'تم استدعاء الروتين, عدد الأسطر المعدلة %d.',
+	'Call' => 'استدعاء',
+	'No extension' => 'امتداد غير موجود',
 	'None of the supported PHP extensions (%s) are available.' => 'إمتدادات php المدعومة غير موجودة.',
 	'Session support must be enabled.' => 'عليك تفعيل نظام الجلسات.',
 	'Session expired, please login again.' => 'إنتهت الجلسة، من فضلك أعد تسجيل الدخول.',
 	'Text length' => 'طول النص',
-	'Foreign key has been dropped.' => 'المفتاح الأجنبي تم مسحه.',
-	'Foreign key has been altered.' => 'المفتاح الأجنبي تم تعديله.',
-	'Foreign key has been created.' => 'المفتاح الأجنبي تم إنشاؤه.',
+	'Foreign key has been dropped.' => 'تم مسح المفتاح الأجنبي.',
+	'Foreign key has been altered.' => 'تم تعديل المفتاح الأجنبي.',
+	'Foreign key has been created.' => 'تم إنشاء المفتاح الأجنبي.',
 	'Foreign key' => 'مفتاح أجنبي',
 	'Target table' => 'الجدول المستهدف',
 	'Change' => 'تعديل',
 	'Source' => 'المصدر',
 	'Target' => 'الهدف',
-	'Add column' => 'أضف عمود',
+	'Add column' => 'إضافة عمودا',
 	'Alter' => 'تعديل',
 	'Add foreign key' => 'إضافة مفتاح أجنبي',
 	'ON DELETE' => 'ON DELETE',
@@ -101,11 +100,11 @@ $translations = array(
 	'View has been created.' => 'تم إنشاء العرض.',
 	'Alter view' => 'تعديل عرض',
 	'Create view' => 'إنشاء عرض',
-	'Name' => 'الإسم',
+	'Name' => 'الاسم',
 	'Process list' => 'قائمة الإجراءات',
 	'%d process(es) have been killed.' => 'عدد الإجراءات التي تم إيقافها %d.',
 	'Kill' => 'إيقاف',
-	'Parameter name' => 'إسم المتغير',
+	'Parameter name' => 'اسم المتغير',
 	'Database schema' => 'مخطط فاعدة البيانات',
 	'Create procedure' => 'إنشاء إجراء',
 	'Create function' => 'إنشاء دالة',
@@ -137,7 +136,7 @@ $translations = array(
 	'Grant' => 'موافق',
 	'Revoke' => 'إلغاء',
 	'%s version: %s through PHP extension %s' => 'النسخة %s : %s عن طريق إمتداد ال PHP %s',
-	'Logged as: %s' => 'تم تسجيل الدخول بإسم %s',
+	'Logged as: %s' => 'تم تسجيل الدخول باسم %s',
 	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'معلومات POST كبيرة جدا. قم بتقليص حجم المعلومات أو قم بزيادة قيمة %s في خيارات ال PHP.',
 	'Move up' => 'نقل للأعلى',
 	'Move down' => 'نقل للأسفل',
@@ -176,7 +175,7 @@ $translations = array(
 	'Data Free' => 'المساحة الحرة',
 	'Rows' => 'الأسطر',
 	',' => ',',
-	'0123456789' => '٠١٢٣٤٥٦٧٨٩',
+	'0123456789' => '0123456789',
 	'Analyze' => 'تحليل',
 	'Optimize' => 'تحسين',
 	'Check' => 'فحص',
@@ -190,11 +189,11 @@ $translations = array(
 	'Maximum number of allowed fields exceeded. Please increase %s.' => 'لقد تجاوزت العدد الأقصى للحقول. يرجى الرفع من %s.',
 	'Partition by' => 'مقسم بواسطة',
 	'Partitions' => 'التقسيمات',
-	'Partition name' => 'إسم التقسيم',
+	'Partition name' => 'اسم التقسيم',
 	'Values' => 'القيم',
-	'%d row(s) have been imported.' => 'عدد الأسطر المستوردة هو %d.',
+	'%d row(s) have been imported.' => 'تم استيراد %d سطرا',
 	'anywhere' => 'في اي مكان',
-	'Import' => 'إستيراد',
+	'Import' => 'استيراد',
 	'Stop on error' => 'أوقف في حالة حدوث خطأ',
 	'%.3f s' => '%.3f s',
 	'$1-$3-$5' => '$5/$3/$1',
@@ -241,7 +240,7 @@ $translations = array(
 	'Alter type' => 'تعديل نوع',
 	'Type has been dropped.' => 'تم حذف النوع.',
 	'Type has been created.' => 'تم إنشاء النوع.',
-	'Use edit link to modify this value.' => 'إستعمل الرابط "تعديل" لتعديل هذه القيمة.',
+	'Use edit link to modify this value.' => 'استعمل الرابط "تعديل" لتعديل هذه القيمة.',
 	'last' => 'الأخيرة',
 	'From server' => 'من الخادم',
 	'System' => 'النظام',
@@ -254,15 +253,15 @@ $translations = array(
 	'Attachments' => 'ملفات مرفقة.',
 	'Item%s has been inserted.' => 'تم إدراج العنصر.',
 	'now' => 'الآن',
-	'%d query(s) executed OK.' => array('تم تنفيذ الإستعلام %d بنجاح.', 'تم تنفيذ الإستعلامات %d بنجاح.'),
-	'Show only errors' => 'إعرض الأخطاء فقط',
+	'%d query(s) executed OK.' => array('تم تنفيذ الاستعلام %d بنجاح.', 'تم تنفيذ الاستعلامات %d بنجاح.'),
+	'Show only errors' => 'إظهار الأخطاء فقط',
 	'Refresh' => 'تحديث',
-	'Invalid schema.' => 'مخطط خاطئ.',
-	'Please use one of the extensions %s.' => 'من فضلك إستعمل إحدى الإمتدادات: %s.',
+	'Invalid schema.' => 'مخطط غير صالح.',
+	'Please use one of the extensions %s.' => 'المرجو استخدام إحدى الامتدادات %s.',
 	'ltr' => 'rtl',
 	'Tables have been copied.' => 'تم نسخ الجداول.',
 	'Copy' => 'نسخ',
-	'Permanent link' => 'وصلة دائمة',
+	'Permanent link' => 'رابط دائم',
 	'Edit all' => 'تعديل الكل',
 	'HH:MM:SS' => 'HH:MM:SS',
 );
