@@ -8,7 +8,6 @@ $translations = array(
 	'Password' => 'Mot de passe',
 	'Select database' => 'Sélectionner la base de données',
 	'Invalid database.' => 'Base de données invalide.',
-	'Create new database' => 'Créer une base de données',
 	'Table has been dropped.' => 'La table a été effacée.',
 	'Table has been altered.' => 'La table a été modifiée.',
 	'Table has been created.' => 'La table a été créée.',
@@ -275,7 +274,7 @@ $translations = array(
 	'File must be in UTF-8 encoding.' => 'Les fichiers doivent être encodés en UTF-8.',
 	'Full table scan' => 'Scan de toute la table',
 	'Too many unsuccessful logins, try again in %d minute(s).' => array('Trop de connexions échouées, essayez à nouveau dans %d minute.', 'Trop de connexions échouées, essayez à nouveau dans %d minutes.'),
-	'Master password expired. <a href="http://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'Le mot de passe a expiré. <a href="http://www.adminer.org/en/extension/" target="_blank">Implémentez</a> la méthode %s afin de le rendre permanent.',
+	'Master password expired. <a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'Le mot de passe a expiré. <a href="https://www.adminer.org/en/extension/" target="_blank">Implémentez</a> la méthode %s afin de le rendre permanent.',
 	'You can upload a big SQL file via FTP and import it from server.' => 'Vous pouvez uploader un gros fichier SQL par FTP et ensuite l\'importer depuis le serveur.',
 	'Size' => 'Taille',
 	'Compute' => 'Calcul',
@@ -283,8 +282,7 @@ $translations = array(
 	'Saving' => 'Enregistrement',
 	'yes' => 'oui',
 	'no' => 'non',
-	'Materialized View' => 'Vue matérialisée',
-	'Create materialized view' => 'Créer une vue matérialisée',
+	'Materialized view' => 'Vue matérialisée',
 	'%d / ' => '%d / ',
 	'Limit rows' => 'Limiter les lignes',
 	'Default value' => 'Valeur par défaut',
