@@ -8,7 +8,6 @@ $translations = array(
 	'Password' => 'Wachtwoord',
 	'Select database' => 'Database selecteren',
 	'Invalid database.' => 'Ongeldige database.',
-	'Create new database' => 'Nieuwe database',
 	'Table has been dropped.' => 'Tabel verwijderd.',
 	'Table has been altered.' => 'Tabel aangepast.',
 	'Table has been created.' => 'Tabel aangemaakt.',
@@ -61,7 +60,7 @@ $translations = array(
 	'Action' => 'Acties',
 	'edit' => 'bewerk',
 	'Page' => 'Pagina',
-	'Query executed OK, %d row(s) affected.' => array('Query uitgevoerd, %d rij geraakt.', 'Query uitgevoerd, %d rijen geraakt.'),
+	'Query executed OK, %d row(s) affected.' => array('Query uitgevoerd, %d rij geraakt.', 'Query uitgevoerd, %d rijen beïnvloed.'),
 	'Error in query' => 'Fout in query',
 	'Execute' => 'Uitvoeren',
 	'Table' => 'Tabel',
