@@ -7,15 +7,14 @@ $translations = array(
 	'Username' => 'Имя пользователя',
 	'Password' => 'Пароль',
 	'Select database' => 'Выбрать базу данных',
-	'Invalid database.' => 'Плохая база данных.',
-	'Create new database' => 'Создать новую базу данных',
+	'Invalid database.' => 'Неверная база данных.',
 	'Table has been dropped.' => 'Таблица была удалена.',
 	'Table has been altered.' => 'Таблица была изменена.',
 	'Table has been created.' => 'Таблица была создана.',
 	'Alter table' => 'Изменить таблицу',
 	'Create table' => 'Создать таблицу',
 	'Table name' => 'Название таблицы',
-	'engine' => 'тип',
+	'engine' => 'Тип таблицы',
 	'collation' => 'режим сопоставления',
 	'Column name' => 'Название поля',
 	'Type' => 'Тип',
@@ -30,27 +29,25 @@ $translations = array(
 	'Database has been altered.' => 'База данных была изменена.',
 	'Alter database' => 'Изменить базу данных',
 	'Create database' => 'Создать базу данных',
-	'SQL command' => 'SQL запрос',
-	'Dump' => 'Дамп',
+	'SQL command' => 'SQL-запрос',
 	'Logout' => 'Выйти',
 	'database' => 'база данных',
 	'Use' => 'Выбрать',
 	'No tables.' => 'В базе данных нет таблиц.',
 	'select' => 'выбрать',
-	'Create new table' => 'Создать новую таблицу',
 	'Item has been deleted.' => 'Запись удалена.',
 	'Item has been updated.' => 'Запись обновлена.',
 	'Item%s has been inserted.' => 'Запись%s была вставлена.',
 	'Edit' => 'Редактировать',
 	'Insert' => 'Вставить',
-	'Save and insert next' => 'Сохранить и вставить еще',
+	'Save and insert next' => 'Сохранить и вставить ещё',
 	'Delete' => 'Стереть',
 	'Database' => 'База данных',
 	'Routines' => 'Хранимые процедуры и функции',
 	'Indexes have been altered.' => 'Индексы изменены.',
 	'Indexes' => 'Индексы',
 	'Alter indexes' => 'Изменить индексы',
-	'Add next' => 'Добавить еще',
+	'Add next' => 'Добавить ещё',
 	'Language' => 'Язык',
 	'Select' => 'Выбрать',
 	'New item' => 'Новая запись',
@@ -62,7 +59,7 @@ $translations = array(
 	'Action' => 'Действие',
 	'edit' => 'редактировать',
 	'Page' => 'Страница',
-	'Query executed OK, %d row(s) affected.' => array('Запрос завершен, изменена %d запись.', 'Запрос завершен, изменены %d записи.', 'Запрос завершен, изменено %d записей.'),
+	'Query executed OK, %d row(s) affected.' => array('Запрос завершён, изменена %d запись.', 'Запрос завершён, изменены %d записи.', 'Запрос завершён, изменено %d записей.'),
 	'Error in query' => 'Ошибка в запросe',
 	'Execute' => 'Выполнить',
 	'Table' => 'Таблица',
@@ -70,7 +67,7 @@ $translations = array(
 	'Triggers' => 'Триггеры',
 	'View' => 'Представление',
 	'Unable to select the table' => 'Не удалось получить данные из таблицы',
-	'Invalid CSRF token. Send the form again.' => 'Недействительный CSRF токен. Отправите форму ещё раз.',
+	'Invalid CSRF token. Send the form again.' => 'Недействительный CSRF-токен. Отправите форму ещё раз.',
 	'Comment' => 'Комментарий',
 	'Default values' => 'Значения по умолчанию',
 	'%d byte(s)' => array('%d байт', '%d байта', '%d байтов'),
@@ -81,25 +78,25 @@ $translations = array(
 	'Routine has been called, %d row(s) affected.' => array('Была вызвана процедура, %d запись была изменена.', 'Была вызвана процедура, %d записи было изменено.', 'Была вызвана процедура, %d записей было изменено.'),
 	'Call' => 'Вызвать',
 	'No extension' => 'Нет расширений',
-	'None of the supported PHP extensions (%s) are available.' => 'Не доступно ни одного расширения из поддерживаемых (%s).',
+	'None of the supported PHP extensions (%s) are available.' => 'Недоступно ни одного расширения из поддерживаемых (%s).',
 	'Session support must be enabled.' => 'Сессии должны быть включены.',
-	'Session expired, please login again.' => 'Срок действия сесси истек, нужно снова войти в систему.',
+	'Session expired, please login again.' => 'Срок действия сессии истёк, нужно снова войти в систему.',
 	'Text length' => 'Длина текста',
-	'Foreign key has been dropped.' => 'Внешний ключ был удален.',
-	'Foreign key has been altered.' => 'Внешний ключ был изменен.',
+	'Foreign key has been dropped.' => 'Внешний ключ был удалён.',
+	'Foreign key has been altered.' => 'Внешний ключ был изменён.',
 	'Foreign key has been created.' => 'Внешний ключ был создан.',
 	'Foreign key' => 'Внешний ключ',
 	'Target table' => 'Результирующая таблица',
 	'Change' => 'Изменить',
 	'Source' => 'Источник',
 	'Target' => 'Цель',
-	'Add column' => 'Добавить колонку',
+	'Add column' => 'Добавить поле',
 	'Alter' => 'Изменить',
 	'Add foreign key' => 'Добавить внешний ключ',
 	'ON DELETE' => 'При стирании',
 	'ON UPDATE' => 'При обновлении',
 	'Index Type' => 'Тип индекса',
-	'Column (length)' => 'Колонка (длина)',
+	'Column (length)' => 'Поле (длина)',
 	'View has been dropped.' => 'Представление было удалено.',
 	'View has been altered.' => 'Представление было изменено.',
 	'View has been created.' => 'Представление было создано.',
@@ -107,7 +104,7 @@ $translations = array(
 	'Create view' => 'Создать представление',
 	'Name' => 'Название',
 	'Process list' => 'Список процессов',
-	'%d process(es) have been killed.' => array('Был завершен %d процесс.', 'Было завершено %d процесса.', 'Было завершёно %d процессов.'),
+	'%d process(es) have been killed.' => array('Был завершён %d процесс.', 'Было завершено %d процесса.', 'Было завершено %d процессов.'),
 	'Kill' => 'Завершить',
 	'Parameter name' => 'Название параметра',
 	'Database schema' => 'Схема базы данных',
@@ -120,8 +117,8 @@ $translations = array(
 	'Alter procedure' => 'Изменить процедуру',
 	'Return type' => 'Возвращаемый тип',
 	'Add trigger' => 'Добавить триггер',
-	'Trigger has been dropped.' => 'Триггер был удален.',
-	'Trigger has been altered.' => 'Триггер был изменен.',
+	'Trigger has been dropped.' => 'Триггер был удалён.',
+	'Trigger has been altered.' => 'Триггер был изменён.',
 	'Trigger has been created.' => 'Триггер был создан.',
 	'Alter trigger' => 'Изменить триггер',
 	'Create trigger' => 'Создать триггер',
@@ -133,15 +130,15 @@ $translations = array(
 	'Are you sure?' => 'Вы уверены?',
 	'Privileges' => 'Полномочия',
 	'Create user' => 'Создать пользователя',
-	'User has been dropped.' => 'Пользователь был удален.',
-	'User has been altered.' => 'Пользователь был изменен.',
+	'User has been dropped.' => 'Пользователь был удалён.',
+	'User has been altered.' => 'Пользователь был изменён.',
 	'User has been created.' => 'Пользователь был создан.',
 	'Hashed' => 'Хешировано',
-	'Column' => 'Колонка',
+	'Column' => 'поле',
 	'Routine' => 'Процедура',
 	'Grant' => 'Позволить',
 	'Revoke' => 'Запретить',
-	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Слишком большой объем POST-данных. Пошлите меньший объем данных или увеличьте параметр конфигурационной директивы %s.',
+	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Слишком большой объем POST-данных. Пошлите меньший объём данных или увеличьте параметр конфигурационной директивы %s.',
 	'Logged as: %s' => 'Вы вошли как: %s',
 	'Move up' => 'Переместить вверх',
 	'Move down' => 'Переместить вниз',
@@ -180,10 +177,11 @@ $translations = array(
 	'Tables have been truncated.' => 'Таблицы были очищены.',
 	'Rows' => 'Строк',
 	',' => ' ',
+	'0123456789' => '0123456789',
 	'Tables have been moved.' => 'Таблицы были перемещены.',
-	'Move to other database' => 'Переместить в другою базу данных',
+	'Move to other database' => 'Переместить в другую базу данных',
 	'Move' => 'Переместить',
-	'Engine' => 'Тип',
+	'Engine' => 'Тип таблиц',
 	'Save and continue edit' => 'Сохранить и продолжить редактирование',
 	'original' => 'исходный',
 	'%d item(s) have been affected.' => array('Была изменена %d запись.', 'Были изменены %d записи.', 'Было изменено %d записей.'),
@@ -197,27 +195,27 @@ $translations = array(
 	'%d row(s) have been imported.' => array('Импортирована %d строка.', 'Импортировано %d строки.', 'Импортировано %d строк.'),
 	'Import' => 'Импорт',
 	'Stop on error' => 'Остановить при ошибке',
-	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Достигнуто максимальное значение количества доступных полей. Увеличьте %s и %s.',
+	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Достигнуто максимальное значение количества доступных полей. Увеличьте %s.',
 	'anywhere' => 'в любом месте',
 	'%.3f s' => '%.3f s',
 	'$1-$3-$5' => '$5.$3.$1',
 	'[yyyy]-mm-dd' => 'дд.мм.[гггг]',
 	'History' => 'История',
 	'Variables' => 'Переменные',
-	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Колонки должны иметь одинаковые типы данных, в результирующей колонке должен быть индекс, данные для импорта должны существовать.',
-	'Relations' => 'Реляции',
+	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Поля должны иметь одинаковые типы данных, в результирующем поле должен быть индекс, данные для импорта должны существовать.',
+	'Relations' => 'Отношения',
 	'Run file' => 'Запустить файл',
 	'Clear' => 'Очистить',
-	'Maximum allowed file size is %sB.' => 'Максимальный разрешенный размер файла - %sB.',
-	'Numbers' => 'Число',
+	'Maximum allowed file size is %sB.' => 'Максимальный разрешённый размер файла — %sB.',
+	'Numbers' => 'Числа',
 	'Date and time' => 'Дата и время',
 	'Strings' => 'Строки',
 	'Binary' => 'Двоичный тип',
 	'Lists' => 'Списки',
 	'Editor' => 'Редактор',
-	'E-mail' => 'Электропочта',
+	'E-mail' => 'Эл. почта',
 	'From' => 'От',
-	'Subject' => 'Кому',
+	'Subject' => 'Тема',
 	'Send' => 'Послать',
 	'%d e-mail(s) have been sent.' => array('Было отправлено %d письмо.', 'Было отправлено %d письма.', 'Было отправлено %d писем.'),
 	'Webserver file %s' => 'Файл %s на вебсервере',
@@ -226,7 +224,6 @@ $translations = array(
 	'Permanent login' => 'Оставаться в системе',
 	'Databases have been dropped.' => 'Базы данных удалены.',
 	'Search data in tables' => 'Поиск в таблицах',
-	'schema' => 'схема',
 	'Schema' => 'Схема',
 	'Alter schema' => 'Изменить схему',
 	'Create schema' => 'Новая схема',
@@ -244,7 +241,7 @@ $translations = array(
 	'Alter type' => 'Изменить тип',
 	'Type has been dropped.' => 'Тип удален.',
 	'Type has been created.' => 'Создан новый тип.',
-	'Double click on a value to modify it.' => 'Кликни два раза по значению, чтобы его изменить.',
+	'Ctrl+click on a value to modify it.' => 'Выполните Ctrl+Щелчок мышью по значению, чтобы его изменить.',
 	'Use edit link to modify this value.' => 'Изменить это значение можно с помощью ссылки «изменить».',
 	'last' => 'последняя',
 	'From server' => 'С сервера',
@@ -255,10 +252,9 @@ $translations = array(
 	'Network' => 'Сеть',
 	'Geometry' => 'Геометрия',
 	'File exists.' => 'Файл уже существует.',
-	'Attachments' => 'Прикрепленные файлы',
+	'Attachments' => 'Прикреплённые файлы',
 	'%d query(s) executed OK.' => array('%d запрос выполнен успешно.', '%d запроса выполнено успешно.', '%d запросов выполнено успешно.'),
 	'Show only errors' => 'Только ошибки',
-	'Last page' => 'Последняя страница',
 	'Refresh' => 'Обновить',
 	'Invalid schema.' => 'Неправильная схема.',
 	'Please use one of the extensions %s.' => 'Используйте одно из этих расширений %s.',
@@ -268,6 +264,33 @@ $translations = array(
 	'Copy' => 'Копировать',
 	'Permanent link' => 'Постоянная ссылка',
 	'Edit all' => 'Редактировать всё',
-	'Resend POST data?' => 'Еще раз послать данные POST запроса?',
 	'HH:MM:SS' => 'ЧЧ:ММ:СС',
+	'Tables have been optimized.' => 'Таблицы оптимизированы.',
+	'Materialized view' => 'Материализованное представление',
+	'Vacuum' => 'Вакуум',
+	'Selected' => 'Выбранные',
+	'Replication' => 'Репликация',
+	'Master status' => 'состояние мастер-сервера',
+	'Slave status' => 'состояние ведомого сервера',
+	'File must be in UTF-8 encoding.' => 'Файл должен быть в кодировке UTF-8.',
+	'Modify' => 'Изменить',
+	'Loading' => 'Загрузка',
+	'Load more data' => 'Загрузить ещё данные',
+	'ATTACH queries are not supported.' => 'ATTACH-запросы не поддерживаются.',
+	'%d / ' => '%d / ',
+	'Limit rows' => 'Лимит строк',
+	'<a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to use SQLite.' => '<a href="https://www.adminer.org/en/extension/" target="_blank">Реализуйте</a> метод %s, чтобы использовать SQLite.',
+	'Default value' => 'Значение по умолчанию',
+	'Full table scan' => 'Анализ полной таблицы',
+	'Too many unsuccessful logins, try again in %d minute(s).' => array('Слишком много неудачных попыток входа. Попробуйте снова через %d минуту.', 'Слишком много неудачных попыток входа. Попробуйте снова через %d минуты.', 'Слишком много неудачных попыток входа. Попробуйте снова через %d минут.'),
+	'Master password expired. <a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'Мастер-пароль истёк. <a href="https://www.adminer.org/en/extension/" target="_blank">Реализуйте</a> метод %s, чтобы сделать его постоянным.',
+	'If you did not send this request from Adminer then close this page.' => 'Если вы не посылали этот запрос из Adminer, закройте эту страницу.',
+	'You can upload a big SQL file via FTP and import it from server.' => 'Вы можете закачать большой SQL-файл по FTP и затем импортировать его с сервера.',
+	'Size' => 'Размер',
+	'Compute' => 'Вычислить',
+	'You are offline.' => 'Вы не выполнили вход.',
+	'You have no privileges to update this table.' => 'У вас нет прав на обновление этой таблицы.',
+	'Saving' => 'Сохранение',
+	'yes' => 'Да',
+	'no' => 'Нет',
 );
