@@ -1,8 +1,8 @@
 <?php
 
 /** Hide some databases from the interface - just to improve design, not a security plugin
-* @link http://www.adminer.org/plugins/#use
-* @author Jakub Vrana, http://www.vrana.cz/
+* @link https://www.adminer.org/plugins/#use
+* @author Jakub Vrana, https://www.vrana.cz/
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
@@ -12,7 +12,7 @@ class AdminerDatabaseHide {
 	/**
 	* @param array case insensitive database names in values
 	*/
-	function AdminerDatabaseHide($disabled) {
+	function __construct($disabled) {
 		$this->disabled = array_map('strtolower', $disabled);
 	}
 	
