@@ -1,15 +1,15 @@
 <?php
 
 /** Select foreign key in edit form
-* @link http://www.adminer.org/plugins/#use
-* @author Jakub Vrana, http://www.vrana.cz/
+* @link https://www.adminer.org/plugins/#use
+* @author Jakub Vrana, https://www.vrana.cz/
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
 class AdminerEditForeign {
 	var $_limit;
 	
-	function AdminerEditForeign($limit = 0) {
+	function __construct($limit = 0) {
 		$this->_limit = $limit;
 	}
 	
@@ -26,7 +26,11 @@ class AdminerEditForeign {
 				$id = $foreignKey["target"][0];
 				$options = &$values[$target][$id];
 				if (!$options) {
-					$options = array("" => "") + get_vals("SELECT " . idf_escape($id) . " FROM " . table($target) . " ORDER BY 1");
+					$column = idf_escape($id);
+					if (preg_match('~binary~', $field["type"])) {
+						$column = "HEX($column)";
+					}
+					$options = array("" => "") + get_vals("SELECT $column FROM " . table($target) . " ORDER BY 1" . ($this->_limit ? " LIMIT " . ($this->_limit + 1) : ""));
 					if ($this->_limit && count($options) - 1 > $this->_limit) {
 						return;
 					}
