@@ -1,8 +1,8 @@
 <?php
 
 /** Allow using Adminer inside a frame (disables ClickJacking protection)
-* @link http://www.adminer.org/plugins/#use
-* @author Jakub Vrana, http://www.vrana.cz/
+* @link https://www.adminer.org/plugins/#use
+* @author Jakub Vrana, https://www.vrana.cz/
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
@@ -13,7 +13,7 @@ class AdminerFrames {
 	/**
 	* @param bool allow running from the same origin only
 	*/
-	function AdminerFrames($sameOrigin = false) {
+	function __construct($sameOrigin = false) {
 		$this->sameOrigin = $sameOrigin;
 	}
 	
