@@ -1,9 +1,9 @@
 <?php
 
 /** Edit all fields containing "_html" by HTML editor TinyMCE and display the HTML in select
-* @link http://www.adminer.org/plugins/#use
+* @link https://www.adminer.org/plugins/#use
 * @uses TinyMCE, http://tinymce.moxiecode.com/
-* @author Jakub Vrana, http://www.vrana.cz/
+* @author Jakub Vrana, https://www.vrana.cz/
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
@@ -14,7 +14,7 @@ class AdminerTinymce {
 	/**
 	* @param string
 	*/
-	function AdminerTinymce($path = "tiny_mce/tiny_mce.js") {
+	function __construct($path = "tiny_mce/tiny_mce.js") {
 		$this->path = $path;
 	}
 
